@@ -92,12 +92,12 @@ col_enum!(
     Remote "remote" "rem": "remote",
     Disk "disk" "dsk": "disk" default,
     Used "used": "used" default,
-    Use "use": "use%" default,
+    Use "use": "use" default,
     UsePercent "use_percent": "use%",
     Free "free": "free" default,
     Size "size": "size" default,
     InodesUsed "inodes_used" "iused": "used inodes",
-    InodesUse "inodes" "ino" "inodes_use" "iuse": "inodes%",
+    InodesUse "inodes" "ino" "inodes_use" "iuse": "inodes",
     InodesUsePercent "inodes_use_percent" "iuse_percent": "inodes%",
     InodesFree "inodes_free" "ifree": "free inodes",
     InodesCount "inodes_total" "inodes_count" "itotal": "inodes total",
